@@ -1,6 +1,6 @@
 package Statocles::Deploy::Git;
 # ABSTRACT: Deploy a site to a Git repository
-$Statocles::Deploy::Git::VERSION = '0.037';
+$Statocles::Deploy::Git::VERSION = '0.038';
 use Statocles::Base 'Class';
 extends 'Statocles::Deploy::File';
 
@@ -31,8 +31,9 @@ around 'deploy' => sub {
     my $current_branch = _current_branch( $git );
     if ( !_has_branch( $git, $self->branch ) ) {
         # Create a new, orphan branch
+        # Orphan branches were introduced in git 1.7.2
         _git_run( $git, checkout => '--orphan', $self->branch );
-        _git_run( $git, 'rm', '-r', '-f', $deploy_dir );
+        _git_run( $git, 'rm', '-r', '-f', '.' );
     }
     else {
         _git_run( $git, checkout => $self->branch );
@@ -42,9 +43,11 @@ around 'deploy' => sub {
     my @files = $self->$orig( $from_store, $message );
 
     # Check to see which files were changed
+    # --porcelain was added in 1.7.0
     my @status_lines = $git->run(
         status => '--porcelain', '--ignore-submodules', '--untracked-files',
     );
+
     my %in_status;
     for my $line ( @status_lines ) {
         my ( $status, $path ) = $line =~ /^\s*(\S+)\s+(.+)$/;
@@ -96,6 +99,13 @@ sub _has_remote {
     return !!grep { $_ eq $remote } map { s/^[\*\s]\s+//; $_ } $git->run( 'remote' );
 }
 
+sub _git_version {
+    my $git_version = ( split ' ', `git --version` )[-1];
+    return unless $git_version;
+    my $v = sprintf '%i.%03i%03i', split /[.]/, $git_version;
+    return $v;
+}
+
 1;
 
 __END__
@@ -108,7 +118,7 @@ Statocles::Deploy::Git - Deploy a site to a Git repository
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 DESCRIPTION
 
